@@ -1,6 +1,6 @@
 /*
  * happydigger - program for cataloging archaeological finds
- * Copyright (C) 2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2004, 2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-void create_db (void);
+#include <sqlite3.h>
+
+gint create_db (gchar *name);
+void find_tables (void);
 gint db_entries (void);
 gint load_from_db (gint line);
 void delete_from_db (gint line);
