@@ -1,6 +1,6 @@
 /*
  * happydigger - program for cataloging archaeological finds
- * Copyright (C) 2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2004, 2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,22 +24,45 @@
 extern GtkWidget *window;
 extern preferencestype preferences;
 
+void
+preview_update (GtkFileChooser *chooser, gpointer data)
+{
+	GtkWidget *image;
+	gchar *filename;
+	gboolean have_preview = FALSE;
+	GdkPixbuf *pixbuf;
+
+	filename = gtk_file_chooser_get_preview_filename (chooser);
+	if (filename)
+	{
+		pixbuf = gdk_pixbuf_new_from_file_at_size (filename, 150, 150, NULL);
+		g_free (filename);
+		if (pixbuf)
+		{
+			have_preview = TRUE;
+			image = gtk_image_new_from_pixbuf (pixbuf);
+			gtk_file_chooser_set_preview_widget (chooser, image);
+			g_object_unref (pixbuf);
+		}
+	}
+	gtk_file_chooser_set_preview_widget_active (chooser, have_preview);
+}
+
 /* clean all entries, do not touch any toolbar entries */
 void clearall (void)
 {
-	GtkWidget *nrentry, *descriptionentry, *typeentry, *materialentry,
-		*periodentry, *notes, *dateentry, *valueentry, *referenceentry,
+	GtkWidget *nrentry, *descriptionentry, *typecombo, *materialcombo,
+		*periodcombo, *notes, *dateentry, *valueentry, *referenceentry,
 		*finddateentry, *locationentry, *coordinatesentry, *spotnotes, 
-		*image1entry, *image2entry, *image1, *image2;
+		*image1entry, *image2entry, *imagebutton1, *imagebutton2;
 	GtkTextBuffer *buffer;
 	GtkTextIter start, end;
-	GdkPixbuf *pixbuf1, *pixbuf2;
 
 	nrentry = lookup_widget (window, "nrentry");
 	descriptionentry = lookup_widget (window, "descriptionentry");
-	typeentry = lookup_widget (window, "typeentry");
-	materialentry = lookup_widget (window, "materialentry");
-	periodentry = lookup_widget (window, "periodentry");
+	typecombo = lookup_widget (window, "typecombo");
+	materialcombo = lookup_widget (window, "materialcombo");
+	periodcombo = lookup_widget (window, "periodcombo");
 	notes = lookup_widget (window, "notes");
 	dateentry = lookup_widget (window, "dateentry");
 	valueentry = lookup_widget (window, "valueentry");
@@ -52,14 +75,14 @@ void clearall (void)
 
 	image1entry = lookup_widget (window, "image1entry");
 	image2entry = lookup_widget (window, "image2entry");
-	image1 = lookup_widget (window, "image1");
-	image2 = lookup_widget (window, "image2");
+	imagebutton1 = lookup_widget (window, "imagebutton1");
+	imagebutton2 = lookup_widget (window, "imagebutton2");
 
 	gtk_editable_delete_text (GTK_EDITABLE (nrentry), 0, -1);
 	gtk_editable_delete_text (GTK_EDITABLE (descriptionentry), 0, -1);
-	gtk_editable_delete_text (GTK_EDITABLE (typeentry), 0, -1);
-	gtk_editable_delete_text (GTK_EDITABLE (materialentry), 0, -1);
-	gtk_editable_delete_text (GTK_EDITABLE (periodentry), 0, -1);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (typecombo), -1);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (materialcombo), -1);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (periodcombo), -1);
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (notes));
 	gtk_text_buffer_get_start_iter (buffer, &start);
 	gtk_text_buffer_get_end_iter (buffer, &end);
@@ -78,16 +101,10 @@ void clearall (void)
 
 	gtk_editable_delete_text (GTK_EDITABLE (image1entry), 0, -1);
 	gtk_editable_delete_text (GTK_EDITABLE (image2entry), 0, -1);
-
-	pixbuf1 = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 100, 100);
-	gdk_pixbuf_fill (pixbuf1, 0x00000000);
-	gtk_image_set_from_pixbuf(GTK_IMAGE(image1), pixbuf1);
-	g_object_unref (pixbuf1);
-
-	pixbuf2 = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 100, 100);
-	gdk_pixbuf_fill (pixbuf2, 0x00000000);
-	gtk_image_set_from_pixbuf(GTK_IMAGE(image2), pixbuf2);
-	g_object_unref (pixbuf2);
+	gtk_container_foreach (GTK_CONTAINER(imagebutton1),
+		(GtkCallback)gtk_widget_destroy, NULL);
+	gtk_container_foreach (GTK_CONTAINER(imagebutton2),
+		(GtkCallback)gtk_widget_destroy, NULL);
 }
 
 /* set popdown strings */
@@ -95,46 +112,38 @@ void set_combostrings (void)
 {
 	GtkWidget *combo;
 	gchar **split;
-	gint i=0;
-	GList *combo_items = NULL;
+	gint i;
 
 	combo = lookup_widget (window, "periodcombo");
 	split = g_strsplit (preferences.periods, ",", 0);
+	i = 0;
 	while (split[i])
 	{
 		g_strstrip (split[i]);
-		combo_items = g_list_append (combo_items, split[i]);
+		gtk_combo_box_append_text (GTK_COMBO_BOX(combo), split[i]);
 		i++;
 	}
-	gtk_combo_set_popdown_strings (GTK_COMBO (combo), combo_items);
-	g_list_free (combo_items);
 	g_strfreev (split);
 
 	combo = lookup_widget (window, "materialcombo");
 	split = g_strsplit (preferences.materials, ",", 0);
 	i = 0;
-	combo_items = NULL;
 	while (split[i])
 	{
 		g_strstrip (split[i]);
-		combo_items = g_list_append (combo_items, split[i]);
+		gtk_combo_box_append_text (GTK_COMBO_BOX(combo), split[i]);
 		i++;
 	}
-	gtk_combo_set_popdown_strings (GTK_COMBO (combo), combo_items);
-	g_list_free (combo_items);
 	g_strfreev (split);
 
 	combo = lookup_widget (window, "typecombo");
 	split = g_strsplit (preferences.types, ",", 0);
 	i = 0;
-	combo_items = NULL;
 	while (split[i])
 	{
 		g_strstrip (split[i]);
-		combo_items = g_list_append (combo_items, split[i]);
+		gtk_combo_box_append_text (GTK_COMBO_BOX(combo), split[i]);
 		i++;
 	}
-	gtk_combo_set_popdown_strings (GTK_COMBO (combo), combo_items);
-	g_list_free (combo_items);
 	g_strfreev (split);
 }
